# -*- coding: utf-8 -*-

from django.core.management.base import BaseCommand, CommandError
from django.conf import settings

from paypal.standard.ipn.models import PayPalIPN
from paypal.standard.models import ST_PP_COMPLETED
from guichet.models import Event, Registration

import re


class Command(BaseCommand):
    help = "Auditer la base de données."

    def add_arguments(self, parser):
        parser.add_argument("event_id", nargs="?", type=int)

    def handle(self, *args, **options):
        event = None
        if options["event_id"]:
            try:
                event = Event.objects.get(pk=options["event_id"])
            except Event.DoesNotExist:
                raise CommandError('Event "{}" does not exist'.format(options["event_id"]))

        ipn = PayPalIPN.objects.filter(flag=False, payment_status=ST_PP_COMPLETED).values_list("invoice", "payer_email")
        for invoice, email in ipn:
            m = re.search(settings.PAYPAL_INVOICE_PREFIX + "([0-9]+)", invoice)
            if m is None:
                self.stderr.write("Bad invoice: {}".format(invoice))
                continue

            reg_id = m.group(1)
            if reg_id in settings.DELETED_REGISTRATIONS:
                continue
            try:
                registration = Registration.objects.get(id=reg_id)
            except Registration.DoesNotExist:
                self.stderr.write("Registration {} not found ({})".format(reg_id, email))
                continue
            if event and registration.ticket.event != event:
                continue
            if not registration.paid:
                self.stderr.write("Registration {} not marked as paid.".format(reg_id))
            elif registration.payment_method not in [Registration.PAYMENT_PAYPAL, Registration.PAYMENT_UNKNOW]:
                self.stderr.write("Registration {} not marked as paid via PayPal or unknown.".format(reg_id))

        if settings.DEBUG:
            self.stdout.write("Verifications completed.")
